Module compute

Module compute 

Defines the operations around performing computations on a loaded model.

Structs

ModelComputation
A wrapper for the loaded machine learning model so we can perform computations on the loaded model.